@@ -6,15 +6,15 @@ class Signals(SignalManager):
     inserted_text = Signal()
     start_indexing = Signal()
     finished_indexing = Signal()
-    extracted_text = Signal(1)
-    updated_dictionary = Signal(1)
-    dictionary = Signal(1)
-    match_found = Signal(1)
+    extracted_text = Signal(object)
+    updated_dictionary = Signal(object)
+    dictionary = Signal(object)
+    match_found = Signal(object)
     no_match_found = Signal()
-    valid_string = Signal(1)
+    valid_string = Signal(object)
     invalid_string = Signal()
     hide_window = Signal()
     show_window = Signal()
     found_indexer_process = Signal()
-    treeview_size = Signal(1)
-    insert_text = Signal(1)
+    treeview_size = Signal(object)
+    insert_text = Signal(object)
